Index: build/android/buildbot/bb_webkit_latest_webkit_tester.sh |
diff --git a/build/android/buildbot/bb_webkit_latest_webkit_tester.sh b/build/android/buildbot/bb_webkit_latest_webkit_tester.sh |
index 61694e8cd3157b9372430bd47a13fea83193f918..76cbfeab171172f8340d8f4747edb507f699fbb0 100755 |
--- a/build/android/buildbot/bb_webkit_latest_webkit_tester.sh |
+++ b/build/android/buildbot/bb_webkit_latest_webkit_tester.sh |
@@ -3,8 +3,8 @@ |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
# |
# Buildbot annotator script for the Webkit latest webkit tester on the |
# webkit canary waterfall. |
BB_DIR="$(dirname $0)" |
BB_SRC_ROOT="$(cd "$BB_DIR/../../.."; pwd)" |
@@ -15,5 +15,5 @@ bb_spawn_logcat_monitor_and_status |
bb_extract_build |
bb_reboot_phones |
# TODO(peter@): Replace this with a test call |
-print "@@@BUILD_STEP TODO Run webit tests@@@" |
+print "@@@BUILD_STEP TODO Run WebKit tests@@@" |
bb_print_logcat |
@@ -3,8 +3,8 @@ |
# found in the LICENSE file. |
# |
-# Buildbot annotator script for the Webkit latest webkit tester on the |
-# webkit canary waterfall. |
+# Buildbot annotator script for the WebKit latest WebKit tester on the |
+# WebKit canary waterfall. |
BB_DIR="$(dirname $0)" |
BB_SRC_ROOT="$(cd "$BB_DIR/../../.."; pwd)" |